#include <iostream>
#include <random>

/*
  Exemple d'utilisation du generateur Mersenne Twister. Le type std::mt19937 n'est defini que dans le standard C++ 11,
  par consequent, la compilation de ce programme avec g++ se fait en ajoutant l'option -std=c++11
*/


int main(void)
{
  std::mt19937 generateur(326); // 326 : graine du generateur (un entier quelconque).

  // On calcule a partir du generateur des variables de lois uniformes sur [0,1]
  std::uniform_real_distribution<double> X1(0,1);
  std::cout << "Variables de loi uniforme sur [0,1]\n";
  for (int i=0; i<10; i++)
	std::cout << X1(generateur) << "\n";

  // Même chose avec des variables de lois uniformes sur [3,5]
  std::uniform_real_distribution<double> X2(3,5);
  std::cout << "-----------------------------------\n";
  std::cout << "Variables de loi uniforme sur [3,5]\n";
  for (int i=0; i<10; i++)
	std::cout << X2(generateur) << "\n";

  // ... des gaussiennes (ici de moyenne 1  et variance 4=2*2)
  std::normal_distribution<double> X3(1,2);
  std::cout << "-----------------------\n";
  std::cout << "Variables de loi N(1,4)\n";
  for (int i=0; i<10; i++)
	std::cout << X3(generateur) << "\n";


  // Il existe aussi les lois
  //
  // std::uniform_int_distribution<int>
  // std::binomial_distribution<int>
  // std::geometric_distribution<int>
  // std::poisson_int_distribution<int>
  // std::exponential_distribution<double>
  //
  // et d'autres...
  return 0;
  
}
